<?php

namespace Elementor;

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Elementor\Core\Schemes;
use Elementor\Utils;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;

/**
 * Elementor tabs widget.
 *
 * Elementor widget that displays vertical or horizontal tabs with different
 * pieces of content.
 *
 * @since 1.0.0
 */
class Erios_Elementor_Link_Showcase extends Widget_Base {

    public function get_categories() {
        return array('erios-addons');
    }

    /**
     * Get widget name.
     *
     * Retrieve tabs widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name() {
        return 'erios-link-showcase';
    }

    /**
     * Get widget title.
     *
     * Retrieve tabs widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title() {
        return esc_html__('Erios Link Showcase', 'erios-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve tabs widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-tabs';
    }

    /**
     * Get widget keywords.
     *
     * Retrieve the list of keywords the widget belongs to.
     *
     * @return array Widget keywords.
     * @since 2.1.0
     * @access public
     *
     */
    public function get_keywords() {
        return ['tabs', 'accordion', 'toggle', 'link', 'showcase'];
    }

    public function get_script_depends() {
        return ['erios-elementor-link-showcase'];
    }

    /**
     * Register tabs widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'section_Heading',
            [
                'label' => esc_html__('Group Heading', 'erios-core'),
            ]
        );

        $this->add_control(
            'title_heading',
            [
                'label' => __('Heading', 'erios-core'),
                'type' => Controls_Manager::TEXT,
                'default' => __('This is the heading', 'erios-core'),
                'placeholder' => __('Enter your heading', 'erios-core'),
                'label_block' => true,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'sub_heading',
            [
                'label' => __('Subheading', 'erios-core'),
                'type' => Controls_Manager::TEXT,
                'default' => 'Subheading',
                'separator' => 'none',
                'label_block' => true,
            ]
        );
        $this->add_control(
            'description_heading',
            [
                'label' => __('Description', 'erios-core'),
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('Click edit button to change this text. Lorem ipsum dolor sit amet consectetur adipiscing elit dolor', 'erios-core'),
                'placeholder' => __('Enter your description', 'erios-core'),
                'separator' => 'none',
                'rows' => 5,
            ]
        );

        $this->end_controls_section();

        $templates = Plugin::instance()->templates_manager->get_source('local')->get_items();
        $options = [
            '0' => '— ' . __('Select', 'erios-core') . ' —',
        ];

        $types = [];

        foreach ($templates as $template) {
            $options[$template['template_id']] = $template['title'] . ' (' . $template['type'] . ')';
            $types[$template['template_id']]   = $template['type'];
        }

        $this->start_controls_section(
            'section_items',
            [
                'label' => esc_html__('Items', 'erios-core'),
            ]
        );

        $repeater = new Repeater();
        $repeater->add_control(
            'title',
            [
                'label'       => esc_html__('link-showcaseText', 'erios-core'),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__('Text', 'erios-core'),
                'placeholder' => esc_html__('Text', 'erios-core'),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'source',
            [
                'label'   => __('Source', 'erios-core'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'html',
                'options' => [
                    'html'     => __('HTML', 'erios-core'),
                    'template' => __('Template', 'erios-core'),
                ],
            ]
        );

        $repeater->add_control(
            'tab_html',
            [
                'label'       => __('Content', 'erios-core'),
                'default'     => __('Tab Content', 'erios-core'),
                'placeholder' => __('Tab Content', 'erios-core'),
                'type'        => Controls_Manager::WYSIWYG,
                'show_label'  => false,
                'condition'   => [
                    'source' => 'html',
                ],
            ]
        );
        $repeater->add_control(
            'tab_template',
            [
                'label'       => __('Choose Template', 'erios-core'),
                'default'     => 0,
                'type'        => Controls_Manager::SELECT,
                'options'     => $options,
                'types'       => $types,
                'label_block' => 'true',
                'condition'   => [
                    'source' => 'template',
                ],
            ]
        );

        $this->add_control(
            'items',
            [
                'label'       => esc_html__('Items', 'erios-core'),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'default'     => [
                    [
                        'title'    => esc_html__('Title #1', 'erios-core'),
                    ],
                    [
                        'title'    => esc_html__('Title #2', 'erios-core'),
                    ],
                    [
                        'title'    => esc_html__('Title #3', 'erios-core'),
                    ],
                ],
                'title_field' => '{{{ title }}}',
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name'      => 'image',
                'default'   => 'full',
                'separator' => 'none',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_button',
            [
                'label' => esc_html__('Button', 'erios-core'),
            ]
        );

        $this->add_control(
            'button_size',
            [
                'label' => __('Size', 'erios-core'),
                'type' => Controls_Manager::SELECT,
                'default' => 'sm',
                'options' => [
                    'xs' => __('Extra Small', 'erios-core'),
                    'sm' => __('Small', 'erios-core'),
                    'md' => __('Medium', 'erios-core'),
                    'lg' => __('Large', 'erios-core'),
                    'xl' => __('Extra Large', 'erios-core'),
                ],
            ]
        );

        $this->add_control(
            'button_type',
            [
                'label' => __('Type', 'erios-core'),
                'type' => Controls_Manager::SELECT,
                'default' => 'primary',
                'options' => [
                    'primary' => __('Primary', 'erios-core'),
                    'secondary' => __('Secondary', 'erios-core'),
                    'dark' => __('Dark', 'erios-core'),
                    'light' => __('Light', 'erios-core'),
                    'link' => __('Link', 'erios-core'),
                    'outline_primary' => __('Outline Primary', 'erios-core'),
                    'outline_secondary' => __('Outline Secondary', 'erios-core'),
                    'outline_dark' => __('Outline Dark', 'erios-core'),
                    'info' => __('Info', 'erios-core'),
                    'success' => __('Success', 'erios-core'),
                    'warning' => __('Warning', 'erios-core'),
                    'danger' => __('Danger', 'erios-core'),
                ],
                'prefix_class' => 'elementor-button-',
            ]
        );

        $this->add_control(
            'button',
            [
                'label' => __('Button Text', 'erios-core'),
                'type' => Controls_Manager::TEXT,
                'default' => __('Click Here', 'erios-core'),
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'button_link',
            [
                'label' => __('Link', 'erios-core'),
                'type' => Controls_Manager::URL,
                'placeholder' => __('https://your-link.com', 'erios-core'),

            ]
        );

        $this->add_control(
            'icon_button',
            [
                'label'       => __('Icon', 'erios-core'),
                'type'        => Controls_Manager::ICON,
                'label_block' => true,
                'default'     => 'opal-icon-long-arrow-right',
            ]
        );

        $this->add_control(
            'icon_align',
            [
                'label'     => __('Position', 'erios-core'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'right',
                'options'   => [
                    'left'  => __('Before', 'erios-core'),
                    'right' => __('After', 'erios-core'),
                ],
                'condition' => [
                    'icon_button!' => '',
                ],
            ]
        );


        $this->end_controls_section();


        $this->start_controls_section(
            'section_group_style',
            [
                'label' => __('Group', 'erios-core'),
                'tab' => Controls_Manager::TAB_STYLE,

            ]
        );


        $this->add_responsive_control(
            'group_width',
            [
                'label' => esc_html__( 'Group Width', 'erios-core' ),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'unit' => '%',
                ],
                'range' => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .link-showcase-title-wrapper' => 'width: {{SIZE}}%',
                ],

            ]
        );

        $this->add_control(
            'group_reverse',
            [
                'label' => __('Group Reverse', 'erios-core'),
                'type' => Controls_Manager::SWITCHER,
                'prefix_class' => 'linkshowcase-group-reverse-',
                'selectors' => [
                    '{{WRAPPER}}.linkshowcase-group-reverse-yes .elementor-link-showcase-inner' => 'flex-direction: row-reverse;',
                ],
            ]

        );


        $this->add_control(
            'group_color',
            [
                'label' => __('Background color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .link-showcase-title-wrapper' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'group_padding',
            [
                'label' => __('Padding', 'erios-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .link-showcase-title-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
                ],

            ]
        );

        $this->add_responsive_control(
            'group_margin',
            [
                'label' => __('Margin', 'erios-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .link-showcase-title-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
                ],

            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'section_heading_style',
            [
                'label' => __('Heading', 'erios-core'),
                'tab' => Controls_Manager::TAB_STYLE,
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'title_heading',
                            'operator' => '!==',
                            'value' => '',
                        ],
                        [
                            'name' => 'sub_heading',
                            'operator' => '!==',
                            'value' => '',
                        ],
                        [
                            'name' => 'description_heading',
                            'operator' => '!==',
                            'value' => '',
                        ],

                    ],
                ],
            ]
        );

        $this->add_responsive_control(
            'group_heading_padding',
            [
                'label' => __('Padding', 'erios-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .link-showcase-group-heading' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
                ],
            ]
        );

        $this->add_control(
            'heading_style_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __('Heading', 'erios-core'),
                'condition' => [
                    'title_heading!' => '',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_heading_typography',
                'selector' => '{{WRAPPER}} .link-showcase-group-heading .title-heading',
                'condition' => [
                    'title_heading!' => '',
                ],
            ]
        );

        $this->add_responsive_control(
            'title__heading_spacing',
            [
                'label' => __('Spacing', 'erios-core'),
                'type' => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .link-showcase-group-heading .title-heading' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'title_heading!' => '',
                ],
            ]
        );

        $this->add_control(
            'title_heading_color',
            [
                'label' => __('Title Heading', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .link-showcase-group-heading .title-heading' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'title_heading!' => '',
                ],
            ]
        );

        $this->add_control(
            'sub_heading_style',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __('Subtitle', 'erios-core'),
                'separator' => 'before',
                'condition' => [
                    'sub_heading!' => '',
                ],
            ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'sub_heading_typography',
                'selector' => '{{WRAPPER}} .link-showcase-group-heading .sub-heading',
                'condition' => [
                    'sub_heading!' => '',
                ],
            ]
        );

        $this->add_responsive_control(
            'sub_heading_spacing',
            [
                'label' => __('Spacing', 'erios-core'),
                'type' => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .link-showcase-group-heading .sub-heading' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'sub_heading!' => '',
                ],
            ]
        );



        $this->add_control(
            'sub_heading_color',
            [
                'label' => __('Sub Heading', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .link-showcase-group-heading .sub-heading' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'sub_heading!' => '',
                ],
            ]
        );



        $this->add_control(
            'description_heading_style',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __('Description', 'erios-core'),
                'separator' => 'before',
                'condition' => [
                    'description_heading!' => '',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'description_heading_typography',
                'selector' => '{{WRAPPER}} .link-showcase-group-heading .description-heading',
                'condition' => [
                    'description_heading!' => '',
                ],
            ]
        );

        $this->add_responsive_control(
            'description_heading_spacing',
            [
                'label' => __('Spacing', 'erios-core'),
                'type' => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .link-showcase-group-heading .description-heading' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'description_heading!' => '',
                ],
            ]
        );
        $this->add_control(
            'description_heading_color',
            [
                'label' => __('Description Heading', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .link-showcase-group-heading .description-heading' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'description_heading!' => '',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_navigation_style',
            [
                'label' => esc_html__( 'Navigation', 'erios-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'navigation_typography',
                'selector' => '{{WRAPPER}} .elementor-link-showcase-title',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_button_style',
            [
                'label' => esc_html__( 'Button', 'erios-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'button_typography',
                'label' => __('Typography', 'erios-core'),
                'selector' => '{{WRAPPER}} .elementor-button',
            ]
        );
        $this->add_control(
            'button_spacing',
            [
                'label' => __('Spacing', 'erios-core'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-button' => 'margin-top: {{SIZE}}{{UNIT}};',
                ]
            ]
        );

        $this->add_control(
            'icon_button_size',
            [
                'label'     => __('Icon Size', 'erios-core'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max' => 50,
                    ],
                ],
                'default'   => [
                    'size' => 14,
                ],
                'condition' => [
                    'icon_button!' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-button .elementor-button-icon i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'icon_button_indent',
            [
                'label'     => __('Icon Spacing', 'erios-core'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max' => 50,
                    ],
                ],
                'default'   => [
                    'size' => 5,
                ],
                'condition' => [
                    'icon_button!' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-button .elementor-align-icon-right' => 'margin-left: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .elementor-button .elementor-align-icon-left'  => 'margin-right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs('button_tabs');

        $this->start_controls_tab('button_normal',
            [
                'label' => __('Normal', 'erios-core'),
            ]
        );

        $this->add_control(
            'button_text_color',
            [
                'label' => __('Text Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-button:not(:hover)' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_background_color',
            [
                'label' => __('Background Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-button:not(:hover)' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'icon_color',
            [
                'label' => __('Icon Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-button:not(:hover) .elementor-button-icon i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'button-hover',
            [
                'label' => __('Hover', 'erios-core'),
            ]
        );

        $this->add_control(
            'button_hover_text_color',
            [
                'label' => __('Text Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-button:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_hover_background_color',
            [
                'label' => __('Background Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-button:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'icon_color_hover',
            [
                'label' => __('Icon Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-button:hover .elementor-button-icon i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_hover_border_color',
            [
                'label' => __('Border Color', 'erios-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-button:hover' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'button_border',
                'selector' => '{{WRAPPER}} .elementor-button',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'button_border_radius',
            [
                'label' => __('Border Radius', 'erios-core'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-button' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'button_padding',
            [
                'label' => __('Padding', 'erios-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .elementor-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render tabs widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        $button_tag = 'a';
       $link_url = empty($settings['button_link']['url']) ? false : $settings['button_link']['url'];

        $this->add_render_attribute('button', 'class', [
            'elementor-button',
            'elementor-size-' . $settings['button_size'],
        ]);

        $this->add_render_attribute('icon-align', 'class',
            [
                'elementor-button-icon',
                'elementor-align-icon-' . $settings['icon_align'],
            ]
        );

        if (!empty($link_url)) {
            $this->add_render_attribute('button', 'href', $link_url);
            if ($settings['button_link']['is_external']) {
                $this->add_render_attribute('button', 'target', '_blank');
            }
        }

        $this->add_inline_editing_attributes('button');

        if (!empty($settings['items']) && is_array($settings['items'])) {
            $items = $settings['items'];
            // Row
            $this->add_render_attribute('wrapper', 'class', 'elementor-link-showcase-wrapper');
            $this->add_render_attribute('row', 'class', 'elementor-link-showcase-inner');
            $id_int = substr($this->get_id_int(), 0, 3);
            ?>
            <div <?php $this->print_render_attribute_string('wrapper'); ?>>
                <div <?php $this->print_render_attribute_string('row'); ?>>
                    <div class="link-showcase-item link-showcase-title-wrapper">
                        <div class="link-showcase-group-heading">
                            <?php if (!empty($settings['sub_heading'])) : ?>
                                <div class="sub-heading">
                                    <?php echo $settings['sub_heading']; ?>
                                </div>
                            <?php endif; ?>

                            <?php if (!empty($settings['title_heading'])) : ?>
                                <h2 class="title-heading">
                                    <?php echo $settings['title_heading']; ?>
                                </h2>
                            <?php endif; ?>

                            <?php if (!empty($settings['description_heading'])) : ?>
                                <div class="description-heading">
                                    <?php echo $settings['description_heading']; ?>
                                </div>
                            <?php endif; ?>
                        </div>
                        <div class="link-showcase-title-inner">
                            <?php foreach ($items as $index => $item) :
                                $count = $index + 1;
                                $item_title_setting_key = $this->get_repeater_setting_key('item_title', 'items', $index);
                                $this->add_render_attribute($item_title_setting_key, [
                                    'id'            => 'elementor-link-showcase-title-' . $id_int . $count,
                                    'class'         => [
                                        'elementor-link-showcase-title',
                                        ($index == 0) ? 'elementor-active' : '',
                                        'elementor-repeater-item-' . $item['_id']
                                    ],
                                    'data-tab'      => $count,
                                    'role'          => 'tab',
                                    'aria-controls' => 'elementor-link-showcase-content-' . $id_int . $count,
                                ]);

                                $title = $item['title'];
                                if (!empty($item['link']['url'])) {
                                    $title = '<a href="' . esc_url($item['link']['url']) . '">' . $title . '</a>';
                                }
                                ?>
                                <div <?php $this->print_render_attribute_string($item_title_setting_key); ?>>
                                    <span class="text"> <?php echo wp_kses_post($title); ?></span>
                                </div>
                            <?php endforeach; ?>
                        </div>
                        <?php
                        if( !empty($settings['button']) || !empty($settings['icon_button']) ){ ?>
                        <div class="elementor-link-showcase__button-wrapper elementor-link-showcase__content-item elementor-content-item <?php echo $animation_class; ?>">
                            <<?php echo $button_tag . ' ' . $this->get_render_attribute_string('button'); ?>>
                            <div class="elementor-button-content-wrapper">
                                <?php if (!empty($settings['icon_button'])) : ?>
                                    <span <?php echo $this->get_render_attribute_string('icon-align'); ?>>
                                        <i class="<?php echo esc_attr($settings['icon_button']); ?>" aria-hidden="true"></i>
                                    </span>
                                <?php endif; ?>
                                <span class="elementor-button-text"><?php echo $settings['button']; ?></span>
                            </div>
                            </<?php echo $button_tag; ?>>
                        </div>
                        <?php } ?>
                    </div>

                    <div class="link-showcase-item link-showcase-contnet-wrapper">
                        <div class="link-showcase-contnet-inner">
                            <?php foreach ($items as $index => $item) :
                                $count = $index + 1;
                                $item_content_setting_key = $this->get_repeater_setting_key('item_content', 'items', $index);
                                $this->add_render_attribute($item_content_setting_key, [
                                    'id'            => 'elementor-link-showcase-content-' . $id_int . $count,
                                    'class'         => [
                                        'elementor-link-showcase-content',
                                        'elementor-repeater-item-' . $item['_id'],
                                        ($index == 0) ? 'elementor-active' : '',
                                    ],
                                    'data-tab'      => $count,
                                    'role'          => 'tab',
                                    'aria-controls' => 'elementor-link-showcase-title-' . $id_int . $count,
                                ]);
                                $title = $item['title'];
                                ?>

                                <div <?php $this->print_render_attribute_string($item_title_setting_key); ?>>
                                    <span class="text"> <?php echo wp_kses_post($title); ?></span>
                                </div>
                                <div <?php $this->print_render_attribute_string($item_content_setting_key); ?>>
                                    <?php if ('html' === $item['source']): ?>
                                        <?php echo do_shortcode($item['tab_html']); ?>
                                    <?php else: ?>
                                        <?php echo Plugin::instance()->frontend->get_builder_content_for_display($item['tab_template']); ?>
                                    <?php endif; ?>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            </div>
            <?php
        }
    }

    private function render_image($settings, $item) {
        if (!empty($item['image']['url'])) :
            ?>
            <?php
            $item['image_size']             = $settings['image_size'];
            $item['image_custom_dimension'] = $settings['image_custom_dimension'];
            echo Group_Control_Image_Size::get_attachment_image_html($item, 'image');
            ?>
        <?php
        endif;
    }
}

$widgets_manager->register_widget_type(new Erios_Elementor_Link_Showcase());
